ahbicht.json\_serialization package
===================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   ahbicht.json_serialization.tree_schema

Module contents
---------------

.. automodule:: ahbicht.json_serialization
   :members:
   :undoc-members:
   :show-inheritance:
